import re
import numpy as np

import zhinst.ziPython
import zhinst.utils

def run_example(port=None, api_level=None):
    """
    Obtain a single demodulator sample and calculate its RMS amplitude.

    Note: This is intended to be a simple example demonstrating how to connect
    to a Zurich Instruments device from ziPython. In most cases, data
    acquistion should use either ziDAQServer's poll() method or an instance of
    the ziDAQRecorder class.
    """
    # open a connection to a Zurich Instruments Server
    daq = zhinst.utils.autoConnect(port, api_level)
    # note: to specify directly which server you connect to please use the
    # following with port=8005 for HF2 and port=8004 for UHF:
    # daq = ziDAQServer('localhost',port)

    # detect device
    device = zhinst.utils.autoDetect(daq)

    # find out whether the device is an HF2 or a UHF
    devtype = daq.getByte('/%s/features/devtype' %device)
    # if the device is a UHF enable the demodulator
    if re.match('UHF',devtype):
        daq.setInt('/%s/demods/0/enable' %device, 1)

    # set the demodulator output rate with syncSet, this command blocks until
    # the setting has taken effect on the device
    rate = daq.syncSetDouble('/%s/demods/0/rate' %device, 1e3)

    # obtain one demodulator sample
    sample = daq.getSample('/%s/demods/0/sample' %device)
    R = np.sqrt(sample['x']**2+sample['y']**2)
    print 'Measured rms amplitude is %fV.' % R
    return R

if __name__ == '__main__':
    R = run_example()
